@@ -2,26 +2,29 @@ __title__ = 'Amino.ed'
 __author__ = 'Alert Aigul'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2022 Alert'
-__version__ = '2.6.3'
+__version__ = '2.7.0'
 
-from asyncio import get_event_loop, sleep, create_task, gather
+from asyncio import sleep, create_task, gather
 from asyncio.events import AbstractEventLoop
 from requests import get
 
-from .global_client import Client
-from .community_client import CommunityClient
-from .utils import exceptions, models, types, helpers
-from .websocket import WebSocketClient
+from .client import Client
+from .websocket import AminoWebSocket
 
-from .utils.helpers import *
-from .utils.types import *
-from .utils.models import *
-from .utils.exceptions import *
+from .helpers.utils import *
+from .helpers.types import *
+from .helpers.models import *
+from .helpers.exceptions import *
+from .helpers.event import *
 
 
-def run_with_client(event_loop: AbstractEventLoop = None, deviceId: str = None):
+def run_with_client(
+    ndc_id: str = None, 
+    device_id: str = None,
+    event_loop: AbstractEventLoop = None
+):
     async def start(loop, callback):
-        async with Client(loop, deviceId) as client:
+        async with Client(ndc_id, device_id, loop) as client:
             await callback(client)
 
     def _start(callback):
@@ -29,6 +32,7 @@ def run_with_client(event_loop: AbstractEventLoop = None, deviceId: str = None):
         loop.run_until_complete(start(loop, callback))
     return _start
 
+
 def run():
     def start(callback):
         loop = get_event_loop()
